@@ -5,6 +5,10 @@ class Error(Exception):
     """Base error class."""
 
 
+class NotAuthenticatedError(Error):
+    """Raised when a request is made to an unathenticated object."""
+
+
 class NotAuthorizedError(Error):
     """Raised when invalid credentials are used."""
 
